Package 'GINAX'

Title: Performs Genome-wide iterative fine-mapping for non-Gaussian data using GINA-X
Description: Implements GINA-X, a genome-wide iterative fine-mapping method designed for non-Gaussian traits. It supports the identification of credible sets of genetic variants.
Authors: Shuangshuang Xu [aut, cre] (ORCID: <https://orcid.org/0009-0006-7262-2978>), Jacob Williams [aut] (ORCID: <https://orcid.org/0000-0002-6425-1365>), Allison Tegge [aut], Marco Ferreira [aut] (ORCID: <https://orcid.org/0000-0002-4705-5661>)
Maintainer: Shuangshuang Xu <[email protected]>
License: GPL-3 + file LICENSE
Version: 0.1.0
Built: 2026-05-13 07:10:45 UTC
Source: https://github.com/xss55/ginax

Help Index


Performs GINA-X as described in the manuscript, Xu, Williams, Tegge, and Ferreira Genome-wide iterative fine-mapping for non-Gaussian data, Nature Genetics, Submitted.

Description

Performs GINA-X as described in the manuscript, Xu, Williams, Tegge, and Ferreira Genome-wide iterative fine-mapping for non-Gaussian data, Nature Genetics, Submitted.

Usage

GINAX(
  Y,
  Covariance,
  SNPs,
  family,
  Z = NULL,
  offset = NULL,
  FDR_Nominal = 0.05,
  maxiterations = 2000,
  runs_til_stop = 400
)

Arguments

Y

The observed phenotypes, count or binary.

Covariance

A list of covariance matrices that are the covariance matrices of the random effects. This matches the list of design matrices in Z.

SNPs

The SNP matrix, where each column represents a single SNP encoded as the numeric coding 0, 1, 2. This is entered as a matrix object.

family

Specify if the response is count ("poisson") or binary ("bernoulli").

Z

A list of matrices specifying the design matrix of each random effect of interest.

offset

If family = "poisson", the offset of each ecotype, can be a vector or a number if the number of offset is the same for each ecotype. If family = "binomial", offset = NULL.

FDR_Nominal

The nominal false discovery rate for which SNPs are selected from in the screening step.

maxiterations

The maximum iterations the genetic algorithm in the model selection step iterates for, defaulted at 2000

runs_til_stop

The number of iterations at the same best model before the genetic algorithm in the model selection step converges, defaulted at 400

Value

The column indices of SNPs that were in the best model identified by GINAX

Examples

data("Y_binary");data("SNPs");data("kinship")
n <- length(Y_binary)
covariance <- list()
covariance[[1]] <- kinship

output_binary <- GINAX(Y=Y_binary, SNPs=SNPs,
                   Covariance=covariance, Z=NULL, family="bernoulli",
                   offset=NULL, FDR_Nominal = 0.05,
                  maxiterations = 1000, runs_til_stop = 200)

Example Dataset1: kinship

Description

This dataset contains kinship matrix.

Usage

data(kinship)

Format

A matrix for kinship

Generated for package example


Example Dataset4: SNPs

Description

This dataset contains all SNPs.

Usage

data(SNPs)

Format

A data frame with 328 rows and 9000 variables

Generated for package example


Example Dataset3: Y_binary

Description

This dataset contains response variable (binary data).

Usage

data(Y_binary)

Format

A vector for binary data

Generated for package example


Example Dataset2: Y_poisson

Description

This dataset contains response variable (count data).

Usage

data(Y_poisson)

Format

A vector for poisson data

Generated for package example